@@ -10,9 +10,19 @@ struct MVMContainerSpec {
     /* Fetches a value out of a container. Used for decontainerization. */
     void (*fetch) (MVMThreadContext *tc, MVMObject *cont, MVMRegister *res);
 
+    /* Native value fetches. */
+    void (*fetch_i) (MVMThreadContext *tc, MVMObject *cont, MVMRegister *res);
+    void (*fetch_n) (MVMThreadContext *tc, MVMObject *cont, MVMRegister *res);
+    void (*fetch_s) (MVMThreadContext *tc, MVMObject *cont, MVMRegister *res);
+
     /* Stores a value in a container. Used for assignment. */
     void (*store) (MVMThreadContext *tc, MVMObject *cont, MVMObject *obj);
 
+    /* Native container stores. */
+    void (*store_i) (MVMThreadContext *tc, MVMObject *cont, MVMint64 value);
+    void (*store_n) (MVMThreadContext *tc, MVMObject *cont, MVMnum64 value);
+    void (*store_s) (MVMThreadContext *tc, MVMObject *cont, MVMString *value);
+
     /* Stores a value in a container, without any checking of it (this
      * assumes an optimizer or something else already did it). Used for
      * assignment. */
@@ -63,3 +73,12 @@ struct MVMContainerRegistry {
 MVM_PUBLIC void MVM_6model_add_container_config(MVMThreadContext *tc, MVMString *name, const MVMContainerConfigurer *configurer);
 const MVMContainerConfigurer * MVM_6model_get_container_config(MVMThreadContext *tc, MVMString *name);
 void MVM_6model_containers_setup(MVMThreadContext *tc);
+MVMint64 MVM_6model_container_iscont_i(MVMThreadContext *tc, MVMObject *cont);
+MVMint64 MVM_6model_container_iscont_n(MVMThreadContext *tc, MVMObject *cont);
+MVMint64 MVM_6model_container_iscont_s(MVMThreadContext *tc, MVMObject *cont);
+void MVM_6model_container_decont_i(MVMThreadContext *tc, MVMObject *cont, MVMRegister *res);
+void MVM_6model_container_decont_n(MVMThreadContext *tc, MVMObject *cont, MVMRegister *res);
+void MVM_6model_container_decont_s(MVMThreadContext *tc, MVMObject *cont, MVMRegister *res);
+void MVM_6model_container_assign_i(MVMThreadContext *tc, MVMObject *cont, MVMint64 value);
+void MVM_6model_container_assign_n(MVMThreadContext *tc, MVMObject *cont, MVMnum64 value);
+void MVM_6model_container_assign_s(MVMThreadContext *tc, MVMObject *cont, MVMString *value);
