@@ -38,6 +38,7 @@
 #include "6model/reprs/ConcBlockingQueue.h"
 #include "6model/reprs/MVMAsyncTask.h"
 #include "6model/reprs/MVMNull.h"
+#include "6model/reprs/NativeRef.h"
 
 /* REPR related functions. */
 void MVM_repr_initialize_registry(MVMThreadContext *tc);
@@ -86,8 +87,9 @@ const MVMREPROps * MVM_repr_get_by_name(MVMThreadContext *tc, MVMString *name);
 #define MVM_REPR_ID_ConcBlockingQueue       36
 #define MVM_REPR_ID_MVMAsyncTask            37
 #define MVM_REPR_ID_MVMNull                 38
+#define MVM_REPR_ID_NativeRef               39
 
-#define MVM_REPR_CORE_COUNT                 39
+#define MVM_REPR_CORE_COUNT                 40
 #define MVM_REPR_MAX_COUNT                  64
 
 /* Default attribute functions for a REPR that lacks them. */
