@@ -14,7 +14,8 @@
 #define MVM_NATIVECALL_ARG_CARRAY          24
 #define MVM_NATIVECALL_ARG_CALLBACK        26
 #define MVM_NATIVECALL_ARG_CPOINTER        28
-#define MVM_NATIVECALL_ARG_TYPE_MASK       30
+#define MVM_NATIVECALL_ARG_VMARRAY         30
+#define MVM_NATIVECALL_ARG_TYPE_MASK       62
 
 /* Flag for whether we should free a string after passing it or not. */
 #define MVM_NATIVECALL_ARG_NO_FREE_STR     0
@@ -73,6 +74,7 @@ MVMObject * MVM_nativecall_global(MVMThreadContext *tc, MVMString *lib, MVMStrin
     MVMObject *target_spec, MVMObject *target_type);
 MVMObject * MVM_nativecall_cast(MVMThreadContext *tc, MVMObject *target_spec,
     MVMObject *res_type, MVMObject *obj);
+MVMint64 MVM_nativecall_sizeof(MVMThreadContext *tc, MVMObject *obj);
 void MVM_nativecall_refresh(MVMThreadContext *tc, MVMObject *cthingy);
 MVMObject * MVM_nativecall_make_cstruct(MVMThreadContext *tc, MVMObject *type, void *cstruct);
 MVMObject * MVM_nativecall_make_cpointer(MVMThreadContext *tc, MVMObject *type, void *ptr);
