@@ -6,6 +6,6 @@ MVMObject * MVM_gc_allocate_object(MVMThreadContext *tc, MVMSTable *st);
 void MVM_gc_allocate_gen2_default_set(MVMThreadContext *tc);
 void MVM_gc_allocate_gen2_default_clear(MVMThreadContext *tc);
 
-#define MVM_gc_allocate(tc, size) (tc->allocate_in == MVMAllocate_Nursery ? \
-    MVM_gc_allocate_nursery(tc, size) : \
-    MVM_gc_gen2_allocate_zeroed(tc->gen2, size))
+#define MVM_gc_allocate(tc, size) (tc->allocate_in_gen2 \
+    ? MVM_gc_gen2_allocate_zeroed(tc->gen2, size) \
+    : MVM_gc_allocate_nursery(tc, size))
