@@ -9,6 +9,8 @@
 
 #if defined _WIN32
 #define MVM_platform_thread_exit(status) ExitThread(0)
+#define MVM_platform_thread_id() (MVMint64)GetCurrentThreadId()
 #else
 #define MVM_platform_thread_exit(status) pthread_exit(status)
+#define MVM_platform_thread_id() (MVMint64)uv_thread_self()
 #endif
