@@ -72,6 +72,9 @@ typedef struct MVMNFABody MVMNFABody;
 typedef struct MVMNFAStateInfo MVMNFAStateInfo;
 typedef struct MVMNativeCall MVMNativeCall;
 typedef struct MVMNativeCallBody MVMNativeCallBody;
+typedef struct MVMNativeRef MVMNativeRef;
+typedef struct MVMNativeRefBody MVMNativeRefBody;
+typedef struct MVMNativeRefREPRData MVMNativeRefREPRData;
 typedef struct MVMNull MVMNull;
 typedef struct MVMNullBody MVMNullBody;
 typedef struct MVMCStr MVMCStr;
